import React, { Component } from "react";
import UserItem from "./UserItem";
import Button from "react-bootstrap/esm/Button";

import DeleteUserModal from './DeleteUserModal'
import EditUser from './EditUser'
import CreateNewUser from './CreateNewUser'
import addIcon from '../../icons/addIcon.png'
import { connect } from "react-redux";
import { bindActionCreators } from "redux";

import * as userManagementActions from '../../actions/UserManagementActions'


const mapStateToProps = state => {
    return {
        showDeleteUserModal: state.UserManagementReducer.showDeleteUserModal,
        userList: state.UserManagementReducer.userList
    };
}

const DISPLAY = {
    LIST: "list",
    EDIT: "edit",
    CREATE: "create"
}

class UserManagement extends Component {
    constructor(props) {
        super(props);
        this.state = {
            displayingPage: DISPLAY.LIST,
            editingUser: null
        }

        this.MapAllUsers = this.MapAllUsers.bind(this);
        this.handleShowDeleteModal = this.handleShowDeleteModal.bind(this);
        this.handleClose = this.handleClose.bind(this);
        this.handleSwitchToList = this.handleSwitchToList.bind(this);
        this.handleShowCreatePage = this.handleShowCreatePage.bind(this);
        this.handleShowEditPage = this.handleShowEditPage.bind(this);
    }

    handleShowDeleteModal(e, dialogModalData) {
        e.preventDefault();
        const { showDeleteUserModalAction } = this.props
        showDeleteUserModalAction(dialogModalData)
    }

    handleShowEditPage(e, user) {
        e.preventDefault();
        this.setState({ editingUser: user })
        this.setState({ displayingPage: DISPLAY.EDIT })
    }

    handleShowCreatePage(e) {
        e.preventDefault();
        this.setState({ displayingPage: DISPLAY.CREATE })
    }

    handleSwitchToList(e) {
        this.setState({ displayingPage: DISPLAY.LIST })
    }

    handleClose() {
        const { hideDeleteUserModalAction } = this.props;
        hideDeleteUserModalAction();
    }


    MapAllUsers() {
        const allUsers = this.props.userList
        if (allUsers) {
            var showDeleteUserModal = this.props.showDeleteUserModal
            if (showDeleteUserModal === undefined) {
                showDeleteUserModal = false
            }
            var users = allUsers.map(user => {
                return (
                    <div key={user.userID}>
                        <UserItem key={user.userID} user={user} handleShowDeleteModal={this.handleShowDeleteModal} handleShowEditPage={this.handleShowEditPage} />
                    </div>
                )
            })
            return users
        }
    }

    render() {
        var workspace
        switch (this.state.displayingPage) {
            case DISPLAY.LIST:
                workspace =
                    <>
                    <h2 style={{textAlign: 'left', color: "white"}}>User-Liste</h2>
                        <div style={{ display: 'flex', justifyContent: "center", width: '5vw', background: '#f8f9fa', borderRadius: '30px' }}>
                            <Button id="UserManagementPageCreateUserButton" onClick={this.handleShowCreatePage} style={{ background: 'transparent', border: 'none' }}>
                                <img alt="Add-User-Button" src={addIcon} style={{ width: '2rem' }}></img>
                            </Button>
                        </div>
                        <div style={{ display: "flex", flexFlow: "row wrap", justifyContent: "left" }}>
                            {this.MapAllUsers()}
                            <DeleteUserModal />
                        </div>
                    </>
                break
            case DISPLAY.CREATE:
                workspace = <CreateNewUser id="UserManagementPageCreateComponent" goBack={this.handleSwitchToList} />
                break
            case DISPLAY.EDIT:
                workspace = <EditUser id="UserManagementPageEditComponent" goBack={this.handleSwitchToList} editUser={this.state.editingUser} />
                break
            default:
                workspace =
                    <>
                        <div style={{ display: 'flex', justifyContent: "center", width: '5vw', background: '#f8f9fa', borderRadius: '30px' }}>
                            <Button id="UserManagementPageCreateUserButton" onClick={this.handleShowCreatePage} style={{ background: 'transparent', border: 'none' }}>
                                <img alt="Add-User-Button" src={addIcon} style={{ width: '2rem' }}></img>
                            </Button>
                        </div>
                        <div style={{ display: "flex", flexFlow: "row wrap" }}>
                            {this.MapAllUsers()}
                            <DeleteUserModal />
                        </div>
                    </>
        }
        return (
            <div id="UserManagementPage" style={{ height: '100vh', backgroundColor: '#2b3648', padding: '1rem' }}>
                {workspace}
            </div>
        )
    }
}

const mapDispatchToProps = dispatch => bindActionCreators({
    showDeleteDegreeCourseModalAction: userManagementActions.getShowDeleteUserModalAction,
    hideDeleteDegreeCourseModalAction: userManagementActions.getHideDeleteUserModalAction
}, dispatch)

const ConnectedUserManagement = connect(mapStateToProps, mapDispatchToProps)(UserManagement)
export default ConnectedUserManagement